<template>
  <div class="app-container">
    <el-button
      size="medium"
      type="primary"
      style="margin-bottom: 10px"
      @click="handleAdd('add',{})"
    >新增</el-button>
    <el-table v-loading="loading" :data="expertList">
      <el-table-column label="平台编号" align="center" type="index"width="80" />
      <el-table-column label="平台名称" align="center" prop="institutionalName" />
      <el-table-column label="AccessKey" align="center" prop="accessKey" />
      <el-table-column label="SecretKey" align="center" prop="secretKey" />
      <el-table-column label="联系人" align="center" prop="contacts" />
      <el-table-column label="联系电话" align="center" prop="phone" />
      <el-table-column label="更新时间" align="center" prop="updateTime" />
      <el-table-column label="是否禁用" align="center" prop="isDisabled" >
        <template #default="scope">
          {{scope.row.status == 0 ? '启用' : '禁用'}}
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template #default="scope">
          <el-button
            size="mini"
            type="text"
            v-if="scope.row.status == 1"
            @click="handleEnable(scope.row)"
          >启用</el-button>
          <el-button
            size="mini"
            type="text"
            v-if="scope.row.status == 0"
            @click="handleEnable(scope.row)"
          >监管禁用</el-button>
          <el-button
            size="mini"
            type="text"
            @click="handleAdd('edit',scope.row)"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            style="color: #f56c6c"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:experts:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
    <add-dialog ref="addDialogRef" @getList = "getList"></add-dialog>
  </div>
</template>

<script>
import addDialog from '@/views/onlineEducation/platformManage/components/addDialog.vue'
import { delExam } from '@/api/coalMine/placeManage/exam'
import { delPlat, listPlat, modPlatStatus } from '@/api/onlineEducation/plat'
export default {
  name: "platformManage",
  components: {addDialog},
  data() {
    return {
      loading: false,
      single: true,
      multiple: true,
      showSearch: true,
      addForm: false,
      total: 0,
      expertList: [],
      queryParams: {
        pageNum: 1,
        pageSize: 10
      },
      classiFy: [],
      form: {},
      rules: {
        classifyName: [
          { required: true, message: "分类名称不能为空", trigger: "blur" }
        ]
      }
    };
  },
  created() {
    this.getList();

  },
  methods: {
    getList(){
      this.loading = true;
      listPlat( this.queryParams).then((res) => {
        if (res.code == 200) {
          this.expertList = res.rows
          this.total = res.total
          this.loading = false;
        }
      })

    },
    handleDelete(val) {
      this.$confirm('删除此条信息，是否继续', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        delPlat( val.id).then((res) => {
          if (res.code == 200) {
            this.$message({
              type:'success',
              message: '删除成功'
            })
            this.getList()
          }
        })
      })
    },
    handleAdd(type,data){
      this.$refs.addDialogRef.openDialog(type, data);
    },
    handleEnable(data){
      if(data.status == 1){
        this.$confirm('确认启用该平台？', '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(() => {
          const param={
            id:data.id,
            status: 0
          }
          modPlatStatus( param).then((res) => {
            if (res.code == 200) {
              this.$message({
                type:'success',
                message: '操作成功'
              })
              this.getList()
            }
          })
        })
      }else {
        this.$confirm('确认禁用该平台？', '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(() => {
          const param={
            id:data.id,
            status: 1
          }
          modPlatStatus( param).then((res) => {
            if (res.code == 200) {
              this.$message({
                type:'success',
                message: '操作成功'
              })
              this.getList()
            }
          })
        })
      }


    },
    handleDisable(data){
      this.$confirm('确认禁用该平台？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        // delExam( val.siteId).then((res) => {
        //   if (res.code == 200) {
        //     this.$message({
        //       type:'success',
        //       message: '删除成功'
        //     })
        //     this.getList()
        //   }
        // })
      })
    },
  }
};
</script>
